Changelog
============


1.0.1 (2023-08-30)
------------

Other
~~~~~~~~~~~~

* `[REF]` Improving linkedin authentication. [Luis Alejandro Martínez Faneyth]

* `[REF]` Fixing test. [Luis Alejandro Martínez Faneyth]


1.0.0 (2023-08-29)
------------

Changed
~~~~~~~~~~~~

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Completing LinkedIn functionality. Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Fixing PR workflow. [Luis Alejandro Martínez Faneyth]

* Developing functions. [Luis Alejandro Martínez Faneyth]

* Changing name to Agora. [Luis Alejandro Martínez Faneyth]

* Developing Instagram and LinkedIn actions. [Luis Alejandro Martínez Faneyth]

* Adding basic functionalities. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Allowing python 3.11 build to fail without failing entire workflow, also on PRs. [Luis Alejandro Martínez Faneyth]

* Allowing python 3.11 build to fail without failing entire workflow. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* `[REF]` Updating version. [Luis Alejandro Martínez Faneyth]

* `[REF]` Improving documentation. [Luis Alejandro Martínez Faneyth]

* `[REF]` Improving documentation. [Luis Alejandro Martínez Faneyth]

* `[REF]` Improving documentation. [Luis Alejandro Martínez Faneyth]

* `[REF]` Improving documentation. [Luis Alejandro Martínez Faneyth]

* `[REF]` Improving documentation. [Luis Alejandro Martínez Faneyth]

* `[REF]` Removing support for python 3.8. [Luis Alejandro Martínez Faneyth]

* Bump sphinx from 7.1.2 to 7.2.2. [dependabot[bot]]

* Bump tox from 4.8.0 to 4.10.0. [dependabot[bot]]

* Bump setuptools from 68.0.0 to 68.1.2. [dependabot[bot]]

* Bump tox from 4.6.4 to 4.8.0. [dependabot[bot]]

* Bump virtualenv from 20.24.2 to 20.24.3. [dependabot[bot]]

* Bump python-facebook-api from 0.15.0 to 0.17.0. [dependabot[bot]]

* Bump sphinx from 7.1.1 to 7.1.2. [dependabot[bot]]

* Bump wheel from 0.41.0 to 0.41.1. [dependabot[bot]]

* Bump sphinx from 7.1.0 to 7.1.1. [dependabot[bot]]

* Bump flake8 from 6.0.0 to 6.1.0. [dependabot[bot]]

* Bump wheel from 0.40.0 to 0.41.0. [dependabot[bot]]

* Bump sphinx from 7.0.1 to 7.1.0. [dependabot[bot]]

* Bump pip from 23.2 to 23.2.1. [dependabot[bot]]

* Bump virtualenv from 20.24.0 to 20.24.2. [dependabot[bot]]

* Bump actions/setup-python from 4.6.1 to 4.7.0. [dependabot[bot]]

* Bump google-auth from 2.21.0 to 2.22.0. [dependabot[bot]]

* Bump virtualenv from 20.23.1 to 20.24.0. [dependabot[bot]]

* Bump pip from 23.1.2 to 23.2. [dependabot[bot]]

* Bump tox from 4.6.3 to 4.6.4. [dependabot[bot]]

* Bump gspread from 5.9.0 to 5.10.0. [dependabot[bot]]

* Bump google-auth from 2.20.0 to 2.21.0. [dependabot[bot]]

* Bump tox from 4.6.2 to 4.6.3. [dependabot[bot]]

* Bump tox from 4.6.0 to 4.6.2. [dependabot[bot]]

* Bump google-auth from 2.19.1 to 2.20.0. [dependabot[bot]]

* Bump virtualenv from 20.23.0 to 20.23.1. [dependabot[bot]]

* Bump setuptools from 67.8.0 to 68.0.0. [dependabot[bot]]

* Bump google-auth from 2.19.0 to 2.19.1. [dependabot[bot]]

* Bump tox from 4.5.2 to 4.6.0. [dependabot[bot]]

* Bump tox from 4.5.1 to 4.5.2. [dependabot[bot]]

* Bump google-auth from 2.18.1 to 2.19.0. [dependabot[bot]]

* Bump actions/setup-python from 4.6.0 to 4.6.1. [dependabot[bot]]

* Bump setuptools from 67.7.2 to 67.8.0. [dependabot[bot]]

* Bump google-auth from 2.18.0 to 2.18.1. [dependabot[bot]]

* Bump google-auth from 2.17.3 to 2.18.0. [dependabot[bot]]

* Bump sphinx from 7.0.0 to 7.0.1. [dependabot[bot]]

* Bump gspread from 5.8.0 to 5.9.0. [dependabot[bot]]

* Bump pip from 23.1.1 to 23.1.2. [dependabot[bot]]

* Bump sphinx from 6.2.0 to 7.0.0. [dependabot[bot]]

* Bump virtualenv from 20.22.0 to 20.23.0. [dependabot[bot]]

* Bump tox from 4.5.0 to 4.5.1. [dependabot[bot]]

* Bump setuptools from 67.6.1 to 67.7.2. [dependabot[bot]]

* Update linkedin-api requirement from ~=2.0.0a5 to ~=2.0.1. [dependabot[bot]]

* Bump tox from 4.4.12 to 4.5.0. [dependabot[bot]]

* Bump virtualenv from 20.21.0 to 20.22.0. [dependabot[bot]]

* Bump tweepy from 4.13.0 to 4.14.0. [dependabot[bot]]

* Bump pip from 23.1 to 23.1.1. [dependabot[bot]]

* Bump sphinx from 6.1.3 to 6.2.0. [dependabot[bot]]

* Bump actions/setup-python from 4.5.0 to 4.6.0. [dependabot[bot]]

* Bump tox from 4.4.11 to 4.4.12. [dependabot[bot]]

* Bump google-auth from 2.17.2 to 2.17.3. [dependabot[bot]]

* Bump pip from 23.0.1 to 23.1. [dependabot[bot]]

* Bump google-auth from 2.17.1 to 2.17.2. [dependabot[bot]]

* Bump setuptools from 67.6.0 to 67.6.1. [dependabot[bot]]

* Bump tox from 4.4.8 to 4.4.11. [dependabot[bot]]

* Bump gspread from 5.7.2 to 5.8.0. [dependabot[bot]]

* Bump google-auth from 2.16.3 to 2.17.1. [dependabot[bot]]

* Bump tox from 4.4.7 to 4.4.8. [dependabot[bot]]

* Bump google-auth from 2.16.2 to 2.16.3. [dependabot[bot]]

* Bump watchdog from 2.3.1 to 3.0.0. [dependabot[bot]]

* Bump wheel from 0.38.4 to 0.40.0. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 3.2.0 to 3.2.1. [dependabot[bot]]

* Bump setuptools from 67.5.1 to 67.6.0. [dependabot[bot]]

* Bump tox from 4.4.6 to 4.4.7. [dependabot[bot]]

* Bump tweepy from 4.12.1 to 4.13.0. [dependabot[bot]]

* Bump virtualenv from 20.20.0 to 20.21.0. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 3.1.0 to 3.2.0. [dependabot[bot]]

* Bump autopep8 from 2.0.1 to 2.0.2. [dependabot[bot]]

* Bump watchdog from 2.3.0 to 2.3.1. [dependabot[bot]]

* Bump google-auth from 2.16.1 to 2.16.2. [dependabot[bot]]

* Bump setuptools from 67.4.0 to 67.5.1. [dependabot[bot]]

* Bump virtualenv from 20.19.0 to 20.20.0. [dependabot[bot]]

* Bump watchdog from 2.2.1 to 2.3.0. [dependabot[bot]]

* Bump tox from 4.4.5 to 4.4.6. [dependabot[bot]]

* Bump setuptools from 67.3.3 to 67.4.0. [dependabot[bot]]

* Bump pip from 23.0 to 23.0.1. [dependabot[bot]]

* Bump google-auth from 2.16.0 to 2.16.1. [dependabot[bot]]

* Bump setuptools from 67.2.0 to 67.3.3. [dependabot[bot]]

* Bump virtualenv from 20.18.0 to 20.19.0. [dependabot[bot]]

* Bump tox from 4.4.4 to 4.4.5. [dependabot[bot]]

* Bump setuptools from 67.1.0 to 67.2.0. [dependabot[bot]]

* Bump virtualenv from 20.17.1 to 20.18.0. [dependabot[bot]]

* Bump setuptools from 67.0.0 to 67.1.0. [dependabot[bot]]

* Bump tox from 4.4.2 to 4.4.4. [dependabot[bot]]

* Bump pip from 22.3.1 to 23.0. [dependabot[bot]]

* Bump tox from 4.3.5 to 4.4.2. [dependabot[bot]]

* Bump setuptools from 66.1.1 to 67.0.0. [dependabot[bot]]

* Bump setuptools from 66.0.0 to 66.1.1. [dependabot[bot]]

* Bump tox from 4.3.3 to 4.3.5. [dependabot[bot]]

* Bump pydocstyle from 6.2.3 to 6.3.0. [dependabot[bot]]

* Bump sphinx from 6.1.2 to 6.1.3. [dependabot[bot]]

* Bump build from 0.9.0 to 0.10.0. [dependabot[bot]]

* Bump tox from 4.2.6 to 4.3.3. [dependabot[bot]]

* Bump setuptools from 65.6.3 to 66.0.0. [dependabot[bot]]

* Bump actions/setup-python from 4.4.0 to 4.5.0. [dependabot[bot]]

* Bump sphinx from 6.0.0 to 6.1.2. [dependabot[bot]]

* Bump pydocstyle from 6.2.0 to 6.2.3. [dependabot[bot]]

* Bump google-auth from 2.15.0 to 2.16.0. [dependabot[bot]]

* Bump tox from 4.1.3 to 4.2.6. [dependabot[bot]]

* Bump actions/setup-python from 4.3.0 to 4.4.0. [dependabot[bot]]

* Bump watchdog from 2.2.0 to 2.2.1. [dependabot[bot]]

* Bump tox from 4.0.15 to 4.1.3. [dependabot[bot]]

* Bump sphinx from 5.3.0 to 6.0.0. [dependabot[bot]]

* Bump pydocstyle from 6.1.1 to 6.2.0. [dependabot[bot]]

* `[REF]` Improving reliability of scripts. [Luis Alejandro Martínez Faneyth]

* `[REF]` Downgrading coverage because coveralls doesnt support version 7 yet. [Luis Alejandro Martínez Faneyth]

* Bump autopep8 from 2.0.0 to 2.0.1. [dependabot[bot]]

* Bump coverage from 6.5.0 to 7.0.0. [dependabot[bot]]

* Bump tox from 4.0.8 to 4.0.15. [dependabot[bot]]

* Bump tox from 3.27.1 to 4.0.8. [dependabot[bot]]

* Bump gspread from 5.7.1 to 5.7.2. [dependabot[bot]]

* Bump virtualenv from 20.17.0 to 20.17.1. [dependabot[bot]]

* Bump google-auth from 2.14.1 to 2.15.0. [dependabot[bot]]

* Bump watchdog from 2.1.9 to 2.2.0. [dependabot[bot]]

* Bump twine from 4.0.1 to 4.0.2. [dependabot[bot]]

* `[REF]` Adding functiona; tests. [Luis Alejandro Martínez Faneyth]

* Bump setuptools from 65.6.0 to 65.6.3. [dependabot[bot]]

* Bump virtualenv from 20.16.7 to 20.17.0. [dependabot[bot]]

* Bump flake8 from 5.0.4 to 6.0.0. [dependabot[bot]]

* Bump setuptools from 65.5.1 to 65.6.0. [dependabot[bot]]

* Bump mako from 1.2.3 to 1.2.4. [dependabot[bot]]

* Bump autopep8 from 1.6.0 to 2.0.0. [dependabot[bot]]

* Update requirements.txt. [Luis Alejandro]

* Bump virtualenv from 20.16.6 to 20.16.7. [dependabot[bot]]

* Bump gspread from 5.6.2 to 5.7.0. [dependabot[bot]]

* Bump tox from 3.27.0 to 3.27.1. [dependabot[bot]]

* Bump wheel from 0.38.2 to 0.38.4. [dependabot[bot]]

* Bump google-auth from 2.14.0 to 2.14.1. [dependabot[bot]]

* Bump setuptools from 65.5.0 to 65.5.1. [dependabot[bot]]

* Bump wheel from 0.37.1 to 0.38.2. [dependabot[bot]]

* Bump tweepy from 4.12.0 to 4.12.1. [dependabot[bot]]

* Bump pip from 22.3 to 22.3.1. [dependabot[bot]]

* Bump google-auth from 2.13.0 to 2.14.0. [dependabot[bot]]

* Bump tox from 3.26.0 to 3.27.0. [dependabot[bot]]

* Bump tweepy from 4.11.0 to 4.12.0. [dependabot[bot]]

* Bump build from 0.8.0 to 0.9.0. [dependabot[bot]]

* Bump virtualenv from 20.16.5 to 20.16.6. [dependabot[bot]]

* Bump google-auth from 2.12.0 to 2.13.0. [dependabot[bot]]

* Bump tweepy from 4.10.1 to 4.11.0. [dependabot[bot]]

* Bump gspread from 5.6.0 to 5.6.2. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 3.0.0 to 3.1.0. [dependabot[bot]]

* Bump pip from 22.2.2 to 22.3. [dependabot[bot]]

* Bump sphinx from 5.2.3 to 5.3.0. [dependabot[bot]]

* Bump setuptools from 65.4.1 to 65.5.0. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 2.4.0 to 3.0.0. [dependabot[bot]]

* Bump google-auth from 2.11.1 to 2.12.0. [dependabot[bot]]

* Bump sphinx from 5.2.1 to 5.2.3. [dependabot[bot]]

* Bump gspread from 5.5.0 to 5.6.0. [dependabot[bot]]

* Bump coverage from 6.4.4 to 6.5.0. [dependabot[bot]]

* Bump setuptools from 65.4.0 to 65.4.1. [dependabot[bot]]

* Bump actions/setup-python from 4.2.0 to 4.3.0. [dependabot[bot]]

* Bump sphinx from 5.1.1 to 5.2.1. [dependabot[bot]]

* Bump mako from 1.2.2 to 1.2.3. [dependabot[bot]]

* Bump setuptools from 65.3.0 to 65.4.0. [dependabot[bot]]

* Bump python-facebook-api from 0.14.5 to 0.15.0. [dependabot[bot]]

* Bump google-auth from 2.11.0 to 2.11.1. [dependabot[bot]]

* Bump actions/checkout from 2 to 3. [dependabot[bot]]

* Bump tox from 3.25.1 to 3.26.0. [dependabot[bot]]

* Bump virtualenv from 20.16.4 to 20.16.5. [dependabot[bot]]

* Bump python-facebook-api from 0.14.3 to 0.14.5. [dependabot[bot]]

* Bump virtualenv from 20.16.3 to 20.16.4. [dependabot[bot]]

* Bump gspread from 5.4.0 to 5.5.0. [dependabot[bot]]

* Bump setuptools from 65.2.0 to 65.3.0. [dependabot[bot]]

* Bump tweepy from 4.10.0 to 4.10.1. [dependabot[bot]]

* Bump mako from 1.2.1 to 1.2.2. [dependabot[bot]]

* Bump setuptools from 65.0.1 to 65.2.0. [dependabot[bot]]

* Bump google-auth from 2.10.0 to 2.11.0. [dependabot[bot]]

* Bump python-facebook-api from 0.14.2 to 0.14.3. [dependabot[bot]]

* Bump coverage from 6.4.3 to 6.4.4. [dependabot[bot]]

* Bump hmarr/auto-approve-action from 2.2.1 to 2.4.0. [dependabot[bot]]

* Bump setuptools from 63.4.2 to 65.0.1. [dependabot[bot]]

* Bump virtualenv from 20.16.2 to 20.16.3. [dependabot[bot]]

* Bump google-auth from 2.9.1 to 2.10.0. [dependabot[bot]]

* Bump coverage from 6.4.2 to 6.4.3. [dependabot[bot]]

* Bump setuptools from 63.3.0 to 63.4.2. [dependabot[bot]]

* Bump flake8 from 5.0.3 to 5.0.4. [dependabot[bot]]

* Bump pip from 22.2.1 to 22.2.2. [dependabot[bot]]

* Bump actions/setup-python from 4.1.0 to 4.2.0. [dependabot[bot]]

* Bump setuptools from 63.2.0 to 63.3.0. [dependabot[bot]]

* Bump virtualenv from 20.16.0 to 20.16.2. [dependabot[bot]]

* Bump flake8 from 4.0.1 to 5.0.3. [dependabot[bot]]

* Bump sphinx from 5.1.0 to 5.1.1. [dependabot[bot]]

* Bump pip from 22.2 to 22.2.1. [dependabot[bot]]

* Bump virtualenv from 20.15.1 to 20.16.0. [dependabot[bot]]

* Bump pip from 22.1.2 to 22.2. [dependabot[bot]]

* Bump sphinx from 5.0.2 to 5.1.0. [dependabot[bot]]

* Bump python-facebook-api from 0.14.1 to 0.14.2. [dependabot[bot]]

* Bump coverage from 6.4.1 to 6.4.2. [dependabot[bot]]

* Bump google-auth from 2.9.0 to 2.9.1. [dependabot[bot]]

* Bump setuptools from 63.1.0 to 63.2.0. [dependabot[bot]]

* Bump actions/setup-python from 3 to 4.1.0. [dependabot[bot]]

* Bump coverage from 6.4 to 6.4.1. [dependabot[bot]]

* Bump python-facebook-api from 0.14.0 to 0.14.1. [dependabot[bot]]

* Bump tox from 3.25.0 to 3.25.1. [dependabot[bot]]

* Bump setuptools from 62.6.0 to 63.1.0. [dependabot[bot]]

* Bump mako from 1.2.0 to 1.2.1. [dependabot[bot]]

* Bump google-auth from 2.8.0 to 2.9.0. [dependabot[bot]]

* Bump virtualenv from 20.15.0 to 20.15.1. [dependabot[bot]]

* Bump watchdog from 2.1.8 to 2.1.9. [dependabot[bot]]

* Bump virtualenv from 20.14.1 to 20.15.0. [dependabot[bot]]

* Bump python-facebook-api from 0.13.1 to 0.14.0. [dependabot[bot]]

* Bump setuptools from 62.4.0 to 62.6.0. [dependabot[bot]]

* Bump google-auth from 2.6.6 to 2.8.0. [dependabot[bot]]

* Bump sphinx from 5.0.1 to 5.0.2. [dependabot[bot]]

* Bump sphinx from 5.0.0 to 5.0.1. [dependabot[bot]]

* Bump setuptools from 62.3.2 to 62.4.0. [dependabot[bot]]

* Bump gspread from 5.3.2 to 5.4.0. [dependabot[bot]]

* Bump pip from 22.1.1 to 22.1.2. [dependabot[bot]]

* Bump gspread from 5.1.1 to 5.3.2. [dependabot[bot]]

* Bump sphinx from 4.5.0 to 5.0.0. [dependabot[bot]]

* Bump tweepy from 4.8.0 to 4.10.0. [dependabot[bot]]

* Update linkedin-api requirement from ~=2.0.0a to ~=2.0.0a5. [dependabot[bot]]

* Bump coverage from 6.3.2 to 6.4. [dependabot[bot]]

* Bump build from 0.7.0 to 0.8.0. [dependabot[bot]]

* Bump pip from 22.0.4 to 22.1.1. [dependabot[bot]]

* Bump setuptools from 62.1.0 to 62.3.2. [dependabot[bot]]

* Bump watchdog from 2.1.7 to 2.1.8. [dependabot[bot]]

* Bump github/codeql-action from 1 to 2. [dependabot[bot]]

* Initial commit. [Luis Alejandro Martínez Faneyth]

